@@ -2,7 +2,7 @@ import json
 from copy import deepcopy
 from pathlib import Path
 from tempfile import NamedTemporaryFile
-from typing import Callable, Generator, List, Optional
+from typing import IO, Generator, List, Optional
 from unittest.mock import MagicMock, patch
 
 import pytest
@@ -19,6 +19,7 @@ from web3.eth import Eth
 
 import raiden_contracts
 from raiden_contracts.constants import (
+    ALDERAAN_VERSION,
     CONTRACT_MONITORING_SERVICE,
     CONTRACT_ONE_TO_N,
     CONTRACT_SECRET_REGISTRY,
@@ -75,26 +76,14 @@ def deployer(web3: Web3) -> ContractDeployer:
 
 
 @pytest.fixture(scope="session")
-def deployer_0_4_0(web3: Web3) -> ContractDeployer:
+def deployer_0_37_0(web3: Web3) -> ContractDeployer:
     return ContractDeployer(
         web3=web3,
         private_key=FAUCET_PRIVATE_KEY,
         gas_limit=GAS_LIMIT,
         gas_price=1,
         wait=10,
-        contracts_version="0.4.0",
-    )
-
-
-@pytest.fixture(scope="session")
-def deployer_0_21_0(web3: Web3) -> ContractDeployer:
-    return ContractDeployer(
-        web3=web3,
-        private_key=FAUCET_PRIVATE_KEY,
-        gas_limit=GAS_LIMIT,
-        gas_price=1,
-        wait=10,
-        contracts_version="0.21.0",
+        contracts_version="0.37.0",
     )
 
 
@@ -120,17 +109,6 @@ def deployed_raiden_info2(deployer: ContractDeployer) -> DeployedContracts:
     )
 
 
-@pytest.mark.slow
-@pytest.fixture(scope="session")
-def deployed_raiden_info_0_4_0(deployer_0_4_0: ContractDeployer) -> DeployedContracts:
-    return deployer_0_4_0.deploy_raiden_contracts(
-        max_num_of_token_networks=None,
-        reuse_secret_registry_from_deploy_file=None,
-        settle_timeout_min=DEPLOY_SETTLE_TIMEOUT_MIN,
-        settle_timeout_max=DEPLOY_SETTLE_TIMEOUT_MAX,
-    )
-
-
 TOKEN_SUPPLY = 10000000
 
 
@@ -173,35 +151,13 @@ def deployed_service_info(
 
 @pytest.mark.slow
 @pytest.fixture(scope="session")
-def test_deploy_service_0_4_0(
-    deployer_0_4_0: ContractDeployer,
+def test_deploy_service_0_37_0(
+    deployer_0_37_0: ContractDeployer,
     token_address: HexAddress,
     token_network_registry_contract: Contract,
 ) -> None:
     with pytest.raises(RuntimeError, match="older service contracts is not supported"):
-        deployer_0_4_0.deploy_service_contracts(
-            token_address=token_address,
-            user_deposit_whole_balance_limit=DEPOSIT_LIMIT,
-            service_registry_controller=DEPLOYER_ADDRESS,
-            initial_service_deposit_price=SERVICE_DEPOSIT // 2,
-            service_deposit_bump_numerator=6,
-            service_deposit_bump_denominator=5,
-            decay_constant=200 * SECONDS_PER_DAY,
-            min_price=1000,
-            registration_duration=180 * SECONDS_PER_DAY,
-            token_network_registry_address=token_network_registry_contract.address,
-        )
-
-
-@pytest.mark.slow
-@pytest.fixture(scope="session")
-def test_deploy_service_0_21_0(
-    deployer_0_21_0: ContractDeployer,
-    token_address: HexAddress,
-    token_network_registry_contract: Contract,
-) -> None:
-    with pytest.raises(RuntimeError, match="older service contracts is not supported"):
-        deployer_0_21_0.deploy_service_contracts(
+        deployer_0_37_0.deploy_service_contracts(
             token_address=token_address,
             user_deposit_whole_balance_limit=DEPOSIT_LIMIT,
             service_registry_controller=DEPLOYER_ADDRESS,
@@ -216,15 +172,7 @@ def test_deploy_service_0_21_0(
 
 
 @pytest.mark.parametrize(
-    "version,expectation",
-    [
-        ("0.3._", False),
-        ("0.4.0", False),
-        ("0.8.0", False),
-        ("0.9.0", True),
-        ("0.10.0", True),
-        (None, True),
-    ],
+    "version,expectation", [(ALDERAAN_VERSION, True), (None, True)],
 )
 def test_contracts_version_with_max_token_networks(
     version: Optional[str], expectation: bool
@@ -233,17 +181,7 @@ def test_contracts_version_with_max_token_networks(
 
 
 @pytest.mark.parametrize(
-    "version,expectation",
-    [
-        ("0.3.0", False),
-        ("0.3._", False),
-        ("0.4.0", False),
-        ("0.8.0", False),
-        ("0.8.0_unlimited", False),
-        ("0.22.0", False),
-        ("0.23.0", True),
-        (None, True),
-    ],
+    "version,expectation", [(ALDERAAN_VERSION, True), (None, True)],
 )
 def test_contracts_version_monitoring_service_takes_token_network_registry(
     version: Optional[str], expectation: bool
@@ -475,85 +413,6 @@ def test_deploy_script_register(
     assert isinstance(token_network_address, str)
 
 
-def test_deploy_script_register_missing_limits(
-    token_network_deposit_limit: int,
-    channel_participant_deposit_limit: int,
-    deployed_raiden_info: DeployedContracts,
-    token_address: ChecksumAddress,
-    deployer: ContractDeployer,
-) -> None:
-    """ Run token register function used in the deployment script
-
-    without the expected channel participant deposit limit.
-    """
-    token_registry_abi = deployer.contract_manager.get_contract_abi(
-        CONTRACT_TOKEN_NETWORK_REGISTRY
-    )
-    token_registry_address = deployed_raiden_info["contracts"][CONTRACT_TOKEN_NETWORK_REGISTRY][
-        "address"
-    ]
-    with pytest.raises(ValueError):
-        deployer.register_token_network(
-            token_registry_abi=token_registry_abi,
-            token_registry_address=token_registry_address,
-            token_address=token_address,
-            channel_participant_deposit_limit=None,
-            token_network_deposit_limit=token_network_deposit_limit,
-        )
-    with pytest.raises(ValueError):
-        deployer.register_token_network(
-            token_registry_abi=token_registry_abi,
-            token_registry_address=token_registry_address,
-            token_address=token_address,
-            channel_participant_deposit_limit=channel_participant_deposit_limit,
-            token_network_deposit_limit=None,
-        )
-    with pytest.raises(ValueError):
-        deployer.register_token_network(
-            token_registry_abi=token_registry_abi,
-            token_registry_address=token_registry_address,
-            token_address=token_address,
-            channel_participant_deposit_limit=None,
-            token_network_deposit_limit=None,
-        )
-
-
-def test_deploy_script_register_unexpected_limits(
-    web3: Web3,
-    token_network_deposit_limit: int,
-    channel_participant_deposit_limit: int,
-    token_address: ChecksumAddress,
-    deployed_raiden_info: DeployedContracts,
-) -> None:
-    """ Run token register function used in the deployment script
-
-    on contracts before the limits were introduced. We don't support that, anymore.
-    """
-    deployer = ContractDeployer(
-        web3=web3,
-        private_key=FAUCET_PRIVATE_KEY,
-        gas_limit=GAS_LIMIT,
-        gas_price=1,
-        wait=10,
-        contracts_version="0.4.0",
-    )
-
-    token_registry_abi = deployer.contract_manager.get_contract_abi(
-        CONTRACT_TOKEN_NETWORK_REGISTRY
-    )
-    token_registry_address = deployed_raiden_info["contracts"][CONTRACT_TOKEN_NETWORK_REGISTRY][
-        "address"
-    ]
-    with pytest.raises(AssertionError, match="Can't deploy old contracts.*limits"):
-        deployer.register_token_network(
-            token_registry_abi=token_registry_abi,
-            token_registry_address=token_registry_address,
-            token_address=token_address,
-            channel_participant_deposit_limit=channel_participant_deposit_limit,
-            token_network_deposit_limit=token_network_deposit_limit,
-        )
-
-
 @pytest.mark.slow
 def test_deploy_script_service(
     web3: Web3,
@@ -863,18 +722,18 @@ def test_store_and_verify_services(
 
 
 @pytest.mark.slow
-def test_red_eyes_deployer(web3: Web3) -> None:
-    """ A smoke test for deploying RedEyes version contracts """
+def test_alderaan_deployer(web3: Web3) -> None:
+    """ A smoke test for deploying Alderaan version contracts """
     deployer = ContractDeployer(
         web3=web3,
         private_key=FAUCET_PRIVATE_KEY,
         gas_limit=GAS_LIMIT,
         gas_price=1,
         wait=10,
-        contracts_version="0.4.0",
+        contracts_version=ALDERAAN_VERSION,
     )
     deployer.deploy_raiden_contracts(
-        max_num_of_token_networks=None,
+        max_num_of_token_networks=2,
         reuse_secret_registry_from_deploy_file=None,
         settle_timeout_min=DEPLOY_SETTLE_TIMEOUT_MIN,
         settle_timeout_max=DEPLOY_SETTLE_TIMEOUT_MAX,
@@ -888,12 +747,7 @@ def test_error_removed_option_raises() -> None:
 
 
 def test_contracts_version_has_initial_service_deposit() -> None:
-    assert not contracts_version_has_initial_service_deposit("0.3._")
-    assert not contracts_version_has_initial_service_deposit("0.4.0")
-    assert not contracts_version_has_initial_service_deposit("0.8.0_unlimited")
-    assert not contracts_version_has_initial_service_deposit("0.9.0")
-    assert not contracts_version_has_initial_service_deposit("0.10.0")
-    assert not contracts_version_has_initial_service_deposit("0.10.1")
+    assert contracts_version_has_initial_service_deposit(ALDERAAN_VERSION)
     assert contracts_version_has_initial_service_deposit(None)
     with pytest.raises(ValueError):
         contracts_version_has_initial_service_deposit("not a semver string")
@@ -931,40 +785,30 @@ def test_deploy_token_invalid_privkey() -> None:
         mock_deployer.assert_not_called()
 
 
-def test_deploy_token_no_balance(get_accounts: Callable, get_private_key: Callable) -> None:
+def test_deploy_token_no_balance(privkey_file: IO) -> None:
     """ Call deploy token command with a private key with no balance """
-    (signer,) = get_accounts(1)
-    priv_key = get_private_key(signer)
-    with NamedTemporaryFile() as privkey_file:
-        privkey_file.write(bytearray(priv_key, "ascii"))
-        privkey_file.flush()
-        with patch.object(
-            ContractDeployer, "deploy_token_contract", spec=ContractDeployer
-        ) as mock_deployer:
-            with patch.object(Eth, "getBalance", return_value=0):
-                runner = CliRunner()
-                result = runner.invoke(token, deploy_token_arguments(privkey=privkey_file.name))
-                assert result.exit_code != 0
-                assert type(result.exception) == RuntimeError
-                assert result.exception.args == ("Account with insufficient funds.",)
-                mock_deployer.assert_not_called()
+    with patch.object(
+        ContractDeployer, "deploy_token_contract", spec=ContractDeployer
+    ) as mock_deployer:
+        with patch.object(Eth, "getBalance", return_value=0):
+            runner = CliRunner()
+            result = runner.invoke(token, deploy_token_arguments(privkey=privkey_file.name))
+            assert result.exit_code != 0
+            assert type(result.exception) == RuntimeError
+            assert result.exception.args == ("Account with insufficient funds.",)
+            mock_deployer.assert_not_called()
 
 
-def test_deploy_token_with_balance(get_accounts: Callable, get_private_key: Callable) -> None:
+def test_deploy_token_with_balance(privkey_file: IO) -> None:
     """ Call deploy token command with a private key with some balance """
-    (signer,) = get_accounts(1)
-    priv_key = get_private_key(signer)
-    with NamedTemporaryFile() as privkey_file:
-        privkey_file.write(bytearray(priv_key, "ascii"))
-        privkey_file.flush()
-        with patch.object(
-            ContractDeployer, "deploy_token_contract", spec=ContractDeployer, return_value={}
-        ) as mock_deployer:
-            with patch.object(Eth, "getBalance", return_value=100):
-                runner = CliRunner()
-                result = runner.invoke(token, deploy_token_arguments(privkey=privkey_file.name))
-                assert result.exit_code == 0
-                mock_deployer.assert_called_once()
+    with patch.object(
+        ContractDeployer, "deploy_token_contract", spec=ContractDeployer, return_value={}
+    ) as mock_deployer:
+        with patch.object(Eth, "getBalance", return_value=100):
+            runner = CliRunner()
+            result = runner.invoke(token, deploy_token_arguments(privkey=privkey_file.name))
+            assert result.exit_code == 0
+            mock_deployer.assert_called_once()
 
 
 def deploy_raiden_arguments(
@@ -994,57 +838,44 @@ def deploy_raiden_arguments(
 
 @patch.object(ContractDeployer, "deploy_raiden_contracts")
 @patch.object(ContractVerifier, "store_and_verify_deployment_info_raiden")
-@pytest.mark.parametrize("contracts_version", [None, "0.4.0"])
+@pytest.mark.parametrize("contracts_version", [None, ALDERAAN_VERSION])
 @pytest.mark.parametrize("reuse_secret_registry", [False, True])
 def test_deploy_raiden(
     mock_deploy: MagicMock,
     mock_verify: MagicMock,
-    get_accounts: Callable,
-    get_private_key: Callable,
     contracts_version: Optional[str],
     reuse_secret_registry: bool,
+    privkey_file: IO,
 ) -> None:
     """ Calling deploy raiden command """
-    (signer,) = get_accounts(1)
-    priv_key = get_private_key(signer)
-    with NamedTemporaryFile() as privkey_file:
-        privkey_file.write(bytearray(priv_key, "ascii"))
-        privkey_file.flush()
-        with patch.object(Eth, "getBalance", return_value=1):
-            runner = CliRunner()
-            result = runner.invoke(
-                raiden,
-                deploy_raiden_arguments(
-                    privkey=privkey_file.name,
-                    save_info=None,
-                    contracts_version=contracts_version,
-                    reuse_secret_registry=reuse_secret_registry,
-                ),
-            )
-            assert result.exception is None
-            assert result.exit_code == 0
-            mock_deploy.assert_called_once()
-            mock_verify.assert_called_once()
+    with patch.object(Eth, "getBalance", return_value=1):
+        runner = CliRunner()
+        result = runner.invoke(
+            raiden,
+            deploy_raiden_arguments(
+                privkey=privkey_file.name,
+                save_info=None,
+                contracts_version=contracts_version,
+                reuse_secret_registry=reuse_secret_registry,
+            ),
+        )
+        assert result.exception is None
+        assert result.exit_code == 0
+        mock_deploy.assert_called_once()
+        mock_verify.assert_called_once()
 
 
 @patch.object(ContractDeployer, "register_token_network")
 def test_register_script(
-    mock_deploy: MagicMock,
-    get_accounts: Callable,
-    get_private_key: Callable,
-    deployed_raiden_info: DeployedContracts,
+    mock_deploy: MagicMock, deployed_raiden_info: DeployedContracts, privkey_file: IO,
 ) -> None:
     """ Calling deploy raiden command """
-    (signer,) = get_accounts(1)
-    priv_key = get_private_key(signer)
-    with NamedTemporaryFile() as privkey_file, patch(
+    with patch(
         "raiden_contracts.deploy.contract_deployer.get_contracts_deployment_info"
     ) as get_deploy_info_mock, patch(
         "raiden_contracts.deploy.__main__._add_token_network_deploy_info"
     ) as add_tn_info:
         get_deploy_info_mock.return_value = deployed_raiden_info
-        privkey_file.write(bytearray(priv_key, "ascii"))
-        privkey_file.flush()
         with patch.object(Eth, "getBalance", return_value=1), patch.object(Eth, "chainId", 61):
             runner = CliRunner()
             result = runner.invoke(
@@ -1073,72 +904,57 @@ def test_register_script(
 
 
 @patch.object(ContractDeployer, "register_token_network")
-def test_register_script_without_token_network(
-    mock_deploy: MagicMock, get_accounts: Callable, get_private_key: Callable
-) -> None:
+def test_register_script_without_token_network(mock_deploy: MagicMock, privkey_file: IO) -> None:
     """ Calling deploy raiden command """
-    (signer,) = get_accounts(1)
-    priv_key = get_private_key(signer)
-    with NamedTemporaryFile() as privkey_file:
-        privkey_file.write(bytearray(priv_key, "ascii"))
-        privkey_file.flush()
-        with patch.object(Eth, "getBalance", return_value=1):
-            runner = CliRunner()
-            result = runner.invoke(
-                register,
-                [
-                    "--rpc-provider",
-                    "rpv_provider",
-                    "--private-key",
-                    privkey_file.name,
-                    "--gas-price",
-                    "12",
-                    "--token-address",
-                    "0x90a16f6aEA062c429c85dc4124ee4b24A00bCc9a",
-                    "--channel-participant-deposit-limit",
-                    "100",
-                    "--token-network-deposit-limit",
-                    "200",
-                ],
-            )
-            assert result.exit_code != 0
-            assert type(result.exception) == RuntimeError
-            assert result.exception.args == (
-                "No TokenNetworkRegistry was specified. "
-                "Add --token-network-registry-address <address>.",
-            )
-            mock_deploy.assert_not_called()
+    with patch.object(Eth, "getBalance", return_value=1):
+        runner = CliRunner()
+        result = runner.invoke(
+            register,
+            [
+                "--rpc-provider",
+                "rpv_provider",
+                "--private-key",
+                privkey_file.name,
+                "--gas-price",
+                "12",
+                "--token-address",
+                "0x90a16f6aEA062c429c85dc4124ee4b24A00bCc9a",
+                "--channel-participant-deposit-limit",
+                "100",
+                "--token-network-deposit-limit",
+                "200",
+            ],
+        )
+        assert result.exit_code != 0
+        assert type(result.exception) == RuntimeError
+        assert result.exception.args == (
+            "No TokenNetworkRegistry was specified. "
+            "Add --token-network-registry-address <address>.",
+        )
+        mock_deploy.assert_not_called()
 
 
 @patch.object(ContractDeployer, "deploy_raiden_contracts")
 @patch.object(ContractDeployer, "verify_deployment_data")
 def test_deploy_raiden_save_info_false(
-    mock_deploy: MagicMock,
-    mock_verify: MagicMock,
-    get_accounts: Callable,
-    get_private_key: Callable,
+    mock_deploy: MagicMock, mock_verify: MagicMock, privkey_file: IO
 ) -> None:
     """ Calling deploy raiden command with --save_info False"""
-    (signer,) = get_accounts(1)
-    priv_key = get_private_key(signer)
-    with NamedTemporaryFile() as privkey_file:
-        privkey_file.write(bytearray(priv_key, "ascii"))
-        privkey_file.flush()
-        with patch.object(Eth, "getBalance", return_value=1):
-            runner = CliRunner()
-            result = runner.invoke(
-                raiden,
-                deploy_raiden_arguments(
-                    privkey=privkey_file.name,
-                    save_info=False,
-                    contracts_version=None,
-                    reuse_secret_registry=False,
-                ),
-            )
-            assert result.exception is None
-            assert result.exit_code == 0
-            mock_deploy.assert_called_once()
-            mock_verify.assert_called_once()
+    with patch.object(Eth, "getBalance", return_value=1):
+        runner = CliRunner()
+        result = runner.invoke(
+            raiden,
+            deploy_raiden_arguments(
+                privkey=privkey_file.name,
+                save_info=False,
+                contracts_version=None,
+                reuse_secret_registry=False,
+            ),
+        )
+        assert result.exception is None
+        assert result.exit_code == 0
+        mock_deploy.assert_called_once()
+        mock_verify.assert_called_once()
 
 
 def deploy_services_arguments(
@@ -1187,118 +1003,87 @@ def deploy_services_arguments(
 
 @patch.object(ContractDeployer, "deploy_service_contracts")
 @patch.object(ContractVerifier, "store_and_verify_deployment_info_services")
-def test_deploy_services(
-    mock_deploy: MagicMock,
-    mock_verify: MagicMock,
-    get_accounts: Callable,
-    get_private_key: Callable,
-) -> None:
+def test_deploy_services(mock_deploy: MagicMock, mock_verify: MagicMock, privkey_file: IO) -> None:
     """ Calling deploy raiden command """
-    (signer,) = get_accounts(1)
-    priv_key = get_private_key(signer)
-    with NamedTemporaryFile() as privkey_file:
-        privkey_file.write(bytearray(priv_key, "ascii"))
-        privkey_file.flush()
-        with patch.object(Eth, "getBalance", return_value=1):
-            runner = CliRunner()
-            result = runner.invoke(
-                services,
-                deploy_services_arguments(
-                    privkey=privkey_file.name,
-                    save_info=None,
-                    service_registry_controller=FAKE_ADDRESS,
-                    token_network_registry_address=FAKE_ADDRESS,
-                ),
-            )
-            assert result.exception is None
-            assert result.exit_code == 0
-            mock_deploy.assert_called_once()
-            mock_verify.assert_called_once()
+    with patch.object(Eth, "getBalance", return_value=1):
+        runner = CliRunner()
+        result = runner.invoke(
+            services,
+            deploy_services_arguments(
+                privkey=privkey_file.name,
+                save_info=None,
+                service_registry_controller=FAKE_ADDRESS,
+                token_network_registry_address=FAKE_ADDRESS,
+            ),
+        )
+        assert result.exception is None
+        assert result.exit_code == 0
+        mock_deploy.assert_called_once()
+        mock_verify.assert_called_once()
 
 
-def test_deploy_old_services(get_accounts: Callable, get_private_key: Callable) -> None:
+def test_deploy_old_services(privkey_file: IO) -> None:
     """ Calling deploy raiden command """
-    (signer,) = get_accounts(1)
-    priv_key = get_private_key(signer)
-    with NamedTemporaryFile() as privkey_file:
-        privkey_file.write(bytearray(priv_key, "ascii"))
-        privkey_file.flush()
-        with patch.object(Eth, "getBalance", return_value=1):
-            runner = CliRunner()
-            result = runner.invoke(
-                services,
-                deploy_services_arguments(
-                    privkey=privkey_file.name,
-                    save_info=None,
-                    service_registry_controller=FAKE_ADDRESS,
-                    token_network_registry_address=FAKE_ADDRESS,
-                    contracts_version="0.21.0",
-                ),
-            )
-            assert result.exception
-            assert result.exit_code == 2
+    with patch.object(Eth, "getBalance", return_value=1):
+        runner = CliRunner()
+        result = runner.invoke(
+            services,
+            deploy_services_arguments(
+                privkey=privkey_file.name,
+                save_info=None,
+                service_registry_controller=FAKE_ADDRESS,
+                token_network_registry_address=FAKE_ADDRESS,
+                contracts_version="0.21.0",
+            ),
+        )
+        assert result.exception
+        assert result.exit_code == 2
 
 
 @patch.object(ContractDeployer, "deploy_service_contracts")
 @patch.object(ContractVerifier, "store_and_verify_deployment_info_services")
 def test_deploy_services_with_controller(
-    mock_deploy: MagicMock,
-    mock_verify: MagicMock,
-    get_accounts: Callable,
-    get_private_key: Callable,
+    mock_deploy: MagicMock, mock_verify: MagicMock, privkey_file: IO
 ) -> None:
     """ Calling deploy raiden command """
-    (signer,) = get_accounts(1)
-    priv_key = get_private_key(signer)
-    with NamedTemporaryFile() as privkey_file:
-        privkey_file.write(bytearray(priv_key, "ascii"))
-        privkey_file.flush()
-        with patch.object(Eth, "getBalance", return_value=1):
-            runner = CliRunner()
-            result = runner.invoke(
-                services,
-                deploy_services_arguments(
-                    privkey=privkey_file.name,
-                    save_info=None,
-                    service_registry_controller=signer,
-                    token_network_registry_address=FAKE_ADDRESS,
-                ),
-            )
-            assert result.exception is None
-            assert result.exit_code == 0
-            mock_deploy.assert_called_once()
-            mock_verify.assert_called_once()
+    with patch.object(Eth, "getBalance", return_value=1):
+        runner = CliRunner()
+        result = runner.invoke(
+            services,
+            deploy_services_arguments(
+                privkey=privkey_file.name,
+                save_info=None,
+                service_registry_controller=HexAddress(HexStr("0x" + "1" * 40)),
+                token_network_registry_address=FAKE_ADDRESS,
+            ),
+        )
+        assert result.exception is None
+        assert result.exit_code == 0
+        mock_deploy.assert_called_once()
+        mock_verify.assert_called_once()
 
 
 @patch.object(ContractDeployer, "deploy_service_contracts")
 @patch.object(ContractDeployer, "verify_service_contracts_deployment_data")
 def test_deploy_services_save_info_false(
-    mock_deploy: MagicMock,
-    mock_verify: MagicMock,
-    get_accounts: Callable,
-    get_private_key: Callable,
+    mock_deploy: MagicMock, mock_verify: MagicMock, privkey_file: IO
 ) -> None:
     """ Calling deploy raiden command with --save_info False"""
-    (signer,) = get_accounts(1)
-    priv_key = get_private_key(signer)
-    with NamedTemporaryFile() as privkey_file:
-        privkey_file.write(bytearray(priv_key, "ascii"))
-        privkey_file.flush()
-        with patch.object(Eth, "getBalance", return_value=1):
-            runner = CliRunner()
-            result = runner.invoke(
-                services,
-                deploy_services_arguments(
-                    privkey=privkey_file.name,
-                    save_info=False,
-                    service_registry_controller=FAKE_ADDRESS,
-                    token_network_registry_address=FAKE_ADDRESS,
-                ),
-            )
-            assert result.exception is None
-            assert result.exit_code == 0
-            mock_deploy.assert_called_once()
-            mock_verify.assert_called_once()
+    with patch.object(Eth, "getBalance", return_value=1):
+        runner = CliRunner()
+        result = runner.invoke(
+            services,
+            deploy_services_arguments(
+                privkey=privkey_file.name,
+                save_info=False,
+                service_registry_controller=FAKE_ADDRESS,
+                token_network_registry_address=FAKE_ADDRESS,
+            ),
+        )
+        assert result.exception is None
+        assert result.exit_code == 0
+        mock_deploy.assert_called_once()
+        mock_verify.assert_called_once()
 
 
 @patch.object(ContractVerifier, "verify_deployed_contracts_in_filesystem")
