@@ -25,7 +25,6 @@ from raiden_contracts.deploy.etherscan_verify import (
     get_constructor_args,
     guid_status,
     join_sources,
-    post_data_for_etherscan_verification,
 )
 
 contract_name = "DummyContract"
@@ -53,8 +52,8 @@ def test_get_constructor_args_one_arg() -> None:
             "metadata": "dummy",
         }
     )
-    deploy_info: DeployedContracts = {  # type: ignore
-        "contracts": {contract_name: {"constructor_arguments": [16]}}
+    deploy_info: DeployedContracts = {
+        "contracts": {contract_name: {"constructor_arguments": [16]}}  # type: ignore
     }
     assert (
         get_constructor_args(deploy_info, contract_name, contract_manager)
@@ -73,8 +72,8 @@ def test_get_constructor_args_two_args() -> None:
             "metadata": "dummy",
         }
     )
-    deploy_info: DeployedContracts = {  # type: ignore
-        "contracts": {contract_name: {"constructor_arguments": [16, True]}}
+    deploy_info: DeployedContracts = {
+        "contracts": {contract_name: {"constructor_arguments": [16, True]}}  # type: ignore
     }
     assert (
         get_constructor_args(deploy_info, contract_name, contract_manager)
@@ -83,32 +82,6 @@ def test_get_constructor_args_two_args() -> None:
     )
 
 
-def test_post_data_for_etherscan_verification() -> None:
-    output = post_data_for_etherscan_verification(
-        apikey="jkl;jkl;jkl;",
-        deployment_info={"address": "dummy_address"},  # type: ignore
-        source="dummy_source",
-        contract_name=contract_name,
-        metadata={
-            "compiler": {"version": "1.2.3"},
-            "settings": {"optimizer": {"enabled": False, "runs": "runs"}},
-        },
-        constructor_args="constructor_arguments",
-    )
-    assert output == {
-        "apikey": "jkl;jkl;jkl;",
-        "module": "contract",
-        "action": "verifysourcecode",
-        "contractaddress": "dummy_address",
-        "sourceCode": "dummy_source",
-        "contractname": contract_name,
-        "compilerversion": "v1.2.3",
-        "optimizationUsed": 0,
-        "runs": "runs",
-        "constructorArguements": "constructor_arguments",
-    }
-
-
 def test_run_join_contracts() -> None:
     """ Just running join_sources() """
     join_sources(DeploymentModule.RAIDEN, CONTRACT_TOKEN_NETWORK_REGISTRY)
@@ -154,11 +127,11 @@ def test_etherscan_verify_already_verified() -> None:
             """,
         )
         runner = CliRunner()
-        result = runner.invoke(
+        runner.invoke(
             etherscan_verify,
             ["--chain-id", str(chain_id), "--apikey", "API", "--contract-name", "SecretRegistry"],
+            catch_exceptions=False,
         )
-        assert result.exit_code == 0
 
 
 def test_etherscan_verify_unknown_error() -> None:
