@@ -3,6 +3,7 @@ from typing import Optional, Tuple
 from hexbytes import HexBytes
 from web3 import Web3
 from web3._utils.threads import Timeout
+from web3.exceptions import TransactionNotFound
 from web3.types import TxData, TxReceipt
 
 
@@ -22,7 +23,7 @@ def check_successful_tx(
             "Does your chain have Byzantium rules enabled?"
         )
     if receipt["status"] == 0:
-        raise ValueError(f"Status 0 indicates failure")
+        raise ValueError("Status 0 indicates failure")
     if txinfo["gas"] == receipt["gasUsed"]:
         raise ValueError(f'Gas is completely used ({txinfo["gas"]}). Failure?')
     return receipt, txinfo
@@ -36,11 +37,8 @@ def wait_for_transaction_receipt(
         while not receipt or not receipt["blockNumber"]:  # pylint: disable=E1136
             try:
                 receipt = web3.eth.getTransactionReceipt(txid)
-            except ValueError as ex:
-                if str(ex).find("EmptyResponse") != -1:
-                    pass  # Empty response from a Parity light client
-                else:
-                    raise ex
+            except TransactionNotFound:
+                pass
             time.sleep(5)
 
     return receipt
